==> rmutil_0.3.tar.gz: rmutil/man/plot.profile.Rd <==
\name{plot.profile}
\title{Plot Marginal Time Profiles}
\usage{
plot.profile(z, times=NULL, nind=1, mu=NULL, add=FALSE, ylim=NULL,
	lty=NULL, ylab="Fitted value", xlab="Time", ...)
}
\alias{plot.profile}
\arguments{
\item{z}{An object of class recursive, from \code{\link{carma}},
\code{\link{gar}}, \code{\link{kalcount}}, \code{\link{kalseries}},
\code{\link{kalsurv}}, or \code{\link{nbkal}}.}
\item{times}{Vector of time points at which profiles are to be plotted.}
\item{nind}{Observation number(s) of individual(s) to be plotted.}
\item{mu}{The location regression as a function of the parameters and
the times, for the desired covariate values.}
\item{add}{If TRUE, add contour to previous plot instead of creating a
new one.}
\item{others}{Plotting control options.}
}
\value{
\code{plot.profile} is used for plotting marginal profiles over time
for models obtained from Kalman fitting, for given fixed values of
covariates. See \code{\link{plot.iprofile}} for plotting individual
profiles.
}
\seealso{
\code{\link{carma}}, \code{\link{gar}}, \code{\link{kalcount}},
\code{\link{kalseries}}, \code{\link{kalsurv}}, \code{\link{nbkal}}
\code{\link{plot.iprofile}}, \code{\link{plot.residuals}}.
}
\examples{
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*tt)-exp(-exp(p[1])*tt)))
shape <- function(p) exp(p[1]-p[2])*tt*dose*exp(-exp(p[1])*tt)
z <- gar(conc, dist="gamma", times, censor=censor, mu=mu, shape=shape,
	preg=c(0.89,-0.77,4), pdep=0.4, psh=c(-1.5,1.17), delta=0.01))
# plot three individual profiles and the average profile
plot.iprofile(z, nind=c(1,12,18), ylim=c(0,1.5), pch=1:3, lty=2:4)
plot.profile(z, nind=c(1,12,18), lty=2:4, add=T)
# or for better resolution
mu1 <- function(p,tt){
   dose <- 50
   exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*tt)-exp(-exp(p[1])*tt)))}
plot.profile(z, times=1:24, mu=mu1, add=T)
}

==> rmutil_0.4.tar.gz: rmutil/man/plot.profile.Rd <==
\name{plot.profile}
\title{Plot Marginal Time Profiles}
\usage{
plot.profile(z, times=NULL, nind=1, mu=NULL, add=FALSE, ylim=NULL,
	lty=NULL, ylab="Fitted value", xlab="Time", ...)
}
\alias{plot.profile}
\arguments{
\item{z}{An object of class recursive, from \code{\link{carma}},
\code{\link{gar}}, \code{\link{kalcount}}, \code{\link{kalseries}},
\code{\link{kalsurv}}, or \code{\link{nbkal}}.}
\item{times}{Vector of time points at which profiles are to be plotted.}
\item{nind}{Observation number(s) of individual(s) to be plotted.}
\item{mu}{The location regression as a function of the parameters and
the times, for the desired covariate values.}
\item{add}{If TRUE, add contour to previous plot instead of creating a
new one.}
\item{others}{Plotting control options.}
}
\value{
\code{plot.profile} is used for plotting marginal profiles over time
for models obtained from Kalman fitting, for given fixed values of
covariates. See \code{\link{plot.iprofile}} for plotting individual
profiles.
}
\author{J.K. Lindsey}
\seealso{
\code{\link{carma}}, \code{\link{gar}}, \code{\link{kalcount}},
\code{\link{kalseries}}, \code{\link{kalsurv}}, \code{\link{nbkal}}
\code{\link{plot.iprofile}}, \code{\link{plot.residuals}}.
}
\examples{
times <- rep(1:20,2)
dose <- c(rep(2,20),rep(5,20))
mu <- function(p) exp(p[1]-p[3])*(dose/(exp(p[1])-exp(p[2]))*
	(exp(-exp(p[2])*times)-exp(-exp(p[1])*times)))
shape <- function(p) exp(p[1]-p[2])*times*dose*exp(-exp(p[1])*times)
conc <- matrix(rgamma(40,1,mu(log(c(1,0.3,0.2)))),ncol=20,byrow=T)
conc[,2:20] <- conc[,2:20]+0.5*(conc[,1:19]-matrix(mu(log(c(1,0.3,0.2))),
	ncol=20,byrow=T)[,1:19])
conc <- ifelse(conc>0,conc,0.01)
z <- gar(conc, dist="gamma", times=1:20, mu=mu, shape=shape,
	preg=log(c(1,0.4,0.1)), pdepend=0.5, pshape=log(c(1,0.2)))
# plot individual profiles and the average profile
plot.iprofile(z, nind=1:2, pch=c(1,20), lty=3:4)
plot.profile(z, nind=1:2, lty=1:2, add=T)
}
